# Testimonials

## Platforms

- **IBM Consulting Advantage**
  [IBM Consulting Advantage](https://www.ibm.com/consulting/advantage) - AI-tooling platform, equipping 160,000 expert consultants with role, industry and business domain-specific AI assistants, agents, and applications.
